## Markdown

Mardown is the language used to write the content of the CBR website. 

It is a simple language that allows you to write text and format it in a way that is easy to read and understand. 

Here are some examples of how you can use Markdown to write content for the CBR website:

### Headers

```# This is a header 1``` will render as:
# this is a header 1

```## This is a header 2``` will render as:
## this is a header 2